==> reakit-1.0.0-alpha.3.tgz: package/src/Dialog/__tests__/Dialog-test.tsx <==
import * as React from "react";
import { render } from "react-testing-library";
import { Dialog } from "../Dialog";

const props: Parameters<typeof Dialog>[0] = {
  unstable_hiddenId: "dialog",
  "aria-label": "dialog"
};

test("render", () => {
  const { baseElement } = render(<Dialog {...props}>dialog</Dialog>);
  expect(baseElement).toMatchInlineSnapshot(`
    <body>
      <div />
      <div
        class="__reakit-portal"
      >
        <div
          aria-hidden="true"
          aria-label="dialog"
          aria-modal="true"
          data-dialog="true"
          hidden=""
          id="dialog"
          role="dialog"
          style="z-index: 999;"
          tabindex="-1"
        >
          dialog
        </div>
      </div>
    </body>
  `);
});

test("render visible", () => {
  const { baseElement } = render(
    <Dialog {...props} visible>
      dialog
    </Dialog>
  );
  expect(baseElement).toMatchInlineSnapshot(`
    <body>
      <div />
      <div
        aria-hidden="true"
        class="__reakit-focus-trap"
        style="position: fixed;"
        tabindex="0"
      />
      <div
        class="__reakit-portal"
      >
        <div
          aria-hidden="false"
          aria-label="dialog"
          aria-modal="true"
          data-dialog="true"
          id="dialog"
          role="dialog"
          style="z-index: 999;"
          tabindex="-1"
        >
          dialog
        </div>
      </div>
      <div
        aria-hidden="true"
        class="__reakit-focus-trap"
        style="position: fixed;"
        tabindex="0"
      />
    </body>
  `);
});

test("render non-modal", () => {
  const { baseElement } = render(
    <Dialog {...props} modal={false}>
      test
    </Dialog>
  );
  expect(baseElement).toMatchInlineSnapshot(`
    <body>
      <div>
        <div
          aria-hidden="true"
          aria-label="dialog"
          aria-modal="false"
          class="__reakit-portal"
          data-dialog="true"
          hidden=""
          id="dialog"
          role="dialog"
          style="z-index: 999;"
          tabindex="-1"
        >
          test
        </div>
      </div>
    </body>
  `);
});

==> reakit-1.3.0-alpha.3.tgz: package/src/Dialog/__tests__/Dialog-test.tsx <==
import * as React from "react";
import { render } from "reakit-test-utils";
import { Dialog } from "../Dialog";

jest.mock("body-scroll-lock");

const props: Parameters<typeof Dialog>[0] = {
  baseId: "base",
  "aria-label": "dialog",
};

test("render", () => {
  const { baseElement } = render(<Dialog {...props}>dialog</Dialog>);
  expect(baseElement).toMatchInlineSnapshot(`
    <body>
      <div />
      <div
        class="__reakit-portal"
      >
        <div
          aria-label="dialog"
          aria-modal="true"
          data-dialog="true"
          hidden=""
          id="base"
          role="dialog"
          style="display: none;"
          tabindex="-1"
        >
          dialog
        </div>
      </div>
    </body>
  `);
});

test("render visible", () => {
  const { baseElement } = render(
    <Dialog {...props} visible>
      dialog
    </Dialog>
  );
  expect(baseElement).toMatchInlineSnapshot(`
    <body>
      <div />
      <div
        aria-hidden="true"
        class="__reakit-focus-trap"
        style="position: fixed;"
        tabindex="0"
      />
      <div
        class="__reakit-portal"
      >
        <div
          aria-label="dialog"
          aria-modal="true"
          data-dialog="true"
          id="base"
          role="dialog"
          tabindex="-1"
        >
          dialog
        </div>
      </div>
      <div
        aria-hidden="true"
        class="__reakit-focus-trap"
        style="position: fixed;"
        tabindex="0"
      />
    </body>
  `);
});

test("render non-modal", () => {
  const { container } = render(
    <Dialog {...props} modal={false}>
      test
    </Dialog>
  );
  expect(container).toMatchInlineSnapshot(`
    <div>
      <div
        aria-label="dialog"
        data-dialog="true"
        hidden=""
        id="base"
        role="dialog"
        style="display: none;"
        tabindex="-1"
      >
        test
      </div>
    </div>
  `);
});
